@@ -2,7 +2,7 @@
 
 readGPS <- function(i="garmin", f="usb:", type="w", invisible=TRUE, ...) {
     GB <- Sys.which("gpsbabel")
-    if (nchar(GB) == 0) stop("gpsbabel not found")
+    if (nchar(GB) == 0 || !file.exists(GB)) stop("gpsbabel not found")
     if (.Platform$OS.type == "windows") 
 	gpsdata <- system(paste(GB, " -", type, " -i ", i, " -f ", f,
 	" -o tabsep -F -", sep=""), intern=TRUE, invisible=invisible)
